@@ -11,7 +11,7 @@ then result in a single EAGLE palette.
 Be creative! do whatever you need to do!
 """
 
-__version__ = "0.1.17"
+__version__ = "0.1.19"
 import json
 import logging
 import os
@@ -28,7 +28,7 @@ try:
 except ImportError:
     from dlg.apps.branch import BranchAppDrop
 
-from dlg.meta import dlg_string_param
+from dlg.meta import dlg_int_param, dlg_string_param
 
 logger = logging.getLogger(__name__)
 
@@ -53,16 +53,13 @@ logger = logging.getLogger(__name__)
 # @param appclass Application class/dlg_example_cmpts.apps.MyBranch/String/ComponentParameter/readonly//False/False/Application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param array Array//Object.Array/InputPort/readwrite//False/False/Port receiving the input array
-# @param Y Y//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean < 0.5
-# @param N N//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean >= 0.5
+# @param array Array//Object.Array/InputPort/readwrite//False/False/Port receiving the input array # noqa: E501
+# @param Y Y//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean < 0.5 # noqa: E501
+# @param N N//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean >= 0.5 # noqa: E501
 # @par EAGLE_END
 
 
 class MyBranch(BranchAppDrop):
-    def initialize(self, **kwargs):
-        BranchAppDrop.initialize(self, **kwargs)
-
     def run(self):
         """
         Just reading the input array and calculating the mean.
@@ -78,7 +75,6 @@ class MyBranch(BranchAppDrop):
         output = self.outputs[self.ind]
         d = pickle.dumps(self.value)
         output.len = len(d)
-        logger.info(f">>>>>>> Writing value {self.value} to output {self.ind}")
         output.write(d)
 
     def condition(self):
@@ -107,9 +103,9 @@ class MyBranch(BranchAppDrop):
 # @param appclass Application class/dlg_example_cmpts.apps.MyBranch/String/ComponentParameter/readonly//False/False/Application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param array Array//Object.Array/InputPort/readwrite//False/False/Port receiving the input array
-# @param Y Y//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean < 0.5
-# @param N N//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean >= 0.5
+# @param array Array//Object.Array/InputPort/readwrite//False/False/Port receiving the input array # noqa: E501
+# @param Y Y//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean < 0.5 # noqa: E501
+# @param N N//float/OutputPort/readwrite//False/False/English Port carrying the mean value of the array if mean >= 0.5 # noqa: E501
 # @par EAGLE_END
 
 
@@ -179,9 +175,9 @@ class LengthCheck(BranchAppDrop):
 # @param appclass Application class/dlg_example_cmpts.apps.FileGlob/String/ComponentParameter/readonly//False/False/Application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param wildcard wildcard/"*"/String/InputPort/readwrite//False/False/Port receiving the search pattern
-# @param filepath filepath/"."/String/InputPort/readwrite//False/False/Port receiving the path to search
-# @param file_list file_list//Object.array/OutputPort/readwrite//False/False/Port carrying the resulting file_list
+# @param wildcard wildcard/"*"/String/InputPort/readwrite//False/False/Port receiving the search pattern # noqa: E501
+# @param filepath filepath/"."/String/InputPort/readwrite//False/False/Port receiving the path to search # noqa: E501
+# @param file_list file_list//Object.array/OutputPort/readwrite//False/False/Port carrying the resulting file_list # noqa: E501
 # @par EAGLE_END
 
 
@@ -191,10 +187,8 @@ class FileGlob(BarrierAppDROP):
     based on a wild-card pattern
     """
 
-    def initialize(self, **kwargs):
-        self.wildcard = self._getArg(kwargs, "wildcard", "*")
-        self.filepath = self._getArg(kwargs, "filepath", ".")
-        BarrierAppDROP.initialize(self, **kwargs)
+    wildcard = dlg_string_param("wildcard", None)
+    filepath = dlg_string_param("filepath", None)
 
     def writeData(self):
         """
@@ -228,12 +222,12 @@ class FileGlob(BarrierAppDROP):
 #
 # @par EAGLE_START
 # @param category PythonApp
-# @param appclass Application Class/dlg_example_cmpts.apps.PickOne/String/ComponentParameter/readonly//False/False/Import path for application class
+# @param appclass Application Class/dlg_example_cmpts.apps.PickOne/String/ComponentParameter/readonly//False/False/Import path for application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param rest_array rest_array//Object.array/InputPort/readwrite//False/FalseList of elements
-# @param element element//Object.element/OutputPort/readwrite//False/False/Port carrying the first element of input array
-# @param rest_array rest_array//Object.array/OutputPort/readwrite//False/False/Port carrying the rest array
+# @param rest_array rest_array//Object.array/InputPort/readwrite//False/FalseList of elements # noqa: E501
+# @param element element//Object.element/OutputPort/readwrite//False/False/Port carrying the first element of input array # noqa: E501
+# @param rest_array rest_array//Object.array/OutputPort/readwrite//False/False/Port carrying the rest array # noqa: E501
 # @par EAGLE_END
 
 
@@ -242,9 +236,6 @@ class PickOne(BarrierAppDROP):
     Simple app picking one element at a time. Good for Loops.
     """
 
-    def initialize(self, **kwargs):
-        BarrierAppDROP.initialize(self, **kwargs)
-
     def readData(self):
         input = self.inputs[0]
         data = pickle.loads(droputils.allDropContents(input))
@@ -292,12 +283,12 @@ class PickOne(BarrierAppDROP):
 #
 # @par EAGLE_START
 # @param category PythonApp
-# @param appclass Application Class/dlg_example_cmpts.apps.ExtractColumn/String/ComponentParameter/readonly//False/False/Import path for application class
+# @param appclass Application Class/dlg_example_cmpts.apps.ExtractColumn/String/ComponentParameter/readonly//False/False/Import path for application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param index index/0/Integer/ApplicationArgument/readwrite//False/False/0-base index of column to extract
-# @param table_array table_array//array/InputPort/readwrite//False/False/List of elements
-# @param column column//Object.1Darray/OutputPort/readwrite//False/False/Port carrying the first element of input array
+# @param index index/0/Integer/ApplicationArgument/readwrite//False/False/0-base index of column to extract # noqa: E501
+# @param table_array table_array//array/InputPort/readwrite//False/False/List of elements # noqa: E501
+# @param column column//Object.1Darray/OutputPort/readwrite//False/False/Port carrying the first element of input array # noqa: E501
 #               the type is dependent on the list element type.
 # @par EAGLE_END
 class ExtractColumn(BarrierAppDROP):
@@ -305,9 +296,7 @@ class ExtractColumn(BarrierAppDROP):
     Simple app extracting a column from a 2D ndarray.
     """
 
-    def initialize(self, **kwargs):
-        self.index = self._getArg(kwargs, "index", 0)
-        BarrierAppDROP.initialize(self, **kwargs)
+    index = dlg_int_param("index", None)
 
     def readData(self):
         input = self.inputs[0]
@@ -343,12 +332,12 @@ class ExtractColumn(BarrierAppDROP):
 # use placeholders to construct the final URL.
 # @par EAGLE_START
 # @param category PythonApp
-# @param appclass Application Class/dlg_example_cmpts.apps.AdvUrlRetrieve/String/ComponentParameter/readonly//False/False/Application class
+# @param appclass Application Class/dlg_example_cmpts.apps.AdvUrlRetrieve/String/ComponentParameter/readonly//False/False/Application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param urlTempl URL Template/"https://eagle.icrar.org"/String/ApplicationArgument/readwrite//False/False/The URL to retrieve
-# @param urlPart URL Part//String/InputPort/readwrite//False/False/The port carrying the content read from the URL.
-# @param content Content//String/OutputPort/readwrite//False/False/The port carrying the content read from the URL.
+# @param urlTempl URL Template/"https://eagle.icrar.org"/String/ApplicationArgument/readwrite//False/False/The URL to retrieve # noqa: E501
+# @param urlPart URL Part//String/InputPort/readwrite//False/False/The port carrying the content read from the URL. # noqa: E501
+# @param content Content//String/OutputPort/readwrite//False/False/The port carrying the content read from the URL. # noqa: E501
 # @par EAGLE_END
 class AdvUrlRetrieve(BarrierAppDROP):
     """
@@ -359,9 +348,7 @@ class AdvUrlRetrieve(BarrierAppDROP):
     URL:   string, URL to retrieve.
     """
 
-    def initialize(self, **kwargs):
-        self.urlTempl = self._getArg(kwargs, "urlTempl", "")
-        BarrierAppDROP.initialize(self, **kwargs)
+    urlTempl = dlg_string_param("urlTempl", None)
 
     def constructUrl(self):
         url = self.urlTempl
@@ -385,6 +372,7 @@ class AdvUrlRetrieve(BarrierAppDROP):
             urlParts.append(part)
         self.urlParts = urlParts
         self.url = self.constructUrl()
+        logger.info("Reading from %s", self.url)
         try:
             u = urllib.request.urlopen(self.url)
         except Exception as e:
@@ -426,20 +414,15 @@ class AdvUrlRetrieve(BarrierAppDROP):
 # JSON value is taken from there.
 # @par EAGLE_START
 # @param category PythonApp
-# @param appclass Application Class/dlg_example_cmpts.apps.String2JSON/String/ComponentParameter/readonly//False/False/Application class
+# @param appclass Application Class/dlg_example_cmpts.apps.String2JSON/String/ComponentParameter/readonly//False/False/Application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param string string//String/InputPort/readwrite//False/False/String to be converted
-# @param element element//Object.json/OutputPort/readwrite//False/False/Port carrying the JSON structure
+# @param string string//String/InputPort/readwrite//False/False/String to be converted # noqa: E501
+# @param element element//Object.json/OutputPort/readwrite//False/False/Port carrying the JSON structure # noqa: E501
 # @par EAGLE_END
 class String2JSON(BarrierAppDROP):
 
-    arg: str = dlg_string_param("string", None)
-
-    def initialize(self, **kwargs):
-        BarrierAppDROP.initialize(self, **kwargs)
-        if not self.arg:
-            self.arg = self._getArg(kwargs, "string", None)
+    string = dlg_string_param("string", None)
 
     def readData(self):
         input = self.inputs[0]  # ignore all but the first
@@ -465,8 +448,8 @@ class String2JSON(BarrierAppDROP):
             len(self.inputs) == 0
         ):  # if there is no input use the argument value
             try:
-                logger.debug("Input found: %s", self.arg)
-                data = json.loads(self.arg)
+                logger.debug("Input found: %s", self.string)
+                data = json.loads(self.string)
             except TypeError:
                 raise
         else:
@@ -484,16 +467,13 @@ class String2JSON(BarrierAppDROP):
 #
 # @par EAGLE_START
 # @param category PythonApp
-# @param appclass Application Class/dlg_example_cmpts.apps.GenericGather/String/ComponentParameter/readonly//False/False/Import path for application class
+# @param appclass Application Class/dlg_example_cmpts.apps.GenericGather/String/ComponentParameter/readonly//False/False/Import path for application class # noqa: E501
 # @param execution_time Execution Time/5/Float/ComponentParameter/readonly//False/False/Estimated execution time # noqa: E501
 # @param num_cpus No. of CPUs/1/Integer/ComponentParameter/readonly//False/False/Number of cores used # noqa: E501
-# @param input input//Object/InputPort/readwrite//False/False/0-base placeholder port for inputs
-# @param output output//Object/OutputPort/readwrite//False/False/Placeholder port for outputs
+# @param input input//Object/InputPort/readwrite//False/False/0-base placeholder port for inputs # noqa: E501
+# @param output output//Object/OutputPort/readwrite//False/False/Placeholder port for outputs # noqa: E501
 # @par EAGLE_END
 class GenericGather(BarrierAppDROP):
-    def initialize(self, **kwargs):
-        BarrierAppDROP.initialize(self, **kwargs)
-
     def readWriteData(self):
 
         inputs = self.inputs
